@@ -6,8 +6,8 @@ namespace panda { namespace log {
 
 struct MultiLogger : ILogger {
     struct Channel {
-        Channel (const ILoggerSP& l, const IFormatterSP& f = {}, Level minl = DEBUG) : logger(l), formatter(f), min_level(minl) {}
-        Channel (const ILoggerSP& l, Level minl)                                     : logger(l), min_level(minl) {}
+        Channel (const ILoggerSP& l, const IFormatterSP& f = {}, Level minl = Level::Debug) : logger(l), formatter(f), min_level(minl) {}
+        Channel (const ILoggerSP& l, Level minl)                                            : logger(l), min_level(minl) {}
         ILoggerSP    logger;
         IFormatterSP formatter;
         Level        min_level;
